;;; utf-8-input.el --- utf-8 input method for GNU Emacs 21.3.1 -*-coding: utf-8-*-

;; Version: 0.1a_5

;; Last Updated: Wed May  7 11:02:13 NZST 2003

;; Maintainer: Richard Mahoney  <r.mahoney@indica-et-buddhica.org>

;; INSTALLATION (on UNIX or UNIX-like system):

;; a) place the following in one's configuration file (~/.emacs.el):

;; (setq load-path (cons "/path/to/utf-8-input_file/" load-path))
;; (prefer-coding-system 'utf-8)
;; (set-terminal-coding-system 'utf-8)
;; (set-selection-coding-system 'utf-8)
;; (modify-coding-system-alist 'file "" 'utf-8)
;; (setq default-enable-multibyte-characters t)
;; (load-library "utf-8-input")
;; (setq default-input-method 'utf-8-input)

;; b) (optional but recommended) modify this file. For e.g., those
;; inputing a good amount of Romanised Sanskrit might like to remap,
;; and thereby reduce, the key strokes required for an under dot,
;; i.e., ("d/."  ?ḍ) --> ("d/" ?ḍ) and ("d/" ?ḋ) --> ("d/." ?ḋ) and so
;; on. The syntax is: ("command sequence" ?utf-8 character).

;; c) (optional) byte compile with: M-x byte-compile-file

;; d) load with: `emacs -debug-init -l ~/.emacs.el -fn \
;; -misc-fixed-medium-r-normal--14-130-75-75-c-70-iso10646-1'

;; e) toggle input method with: C-\

;;; Credits: Stefan Baums for introducing me to this input method

;;; This file contains multibyte non-ASCII characters
;;; and therefore cannot be loaded into Emacs 19.

(if (and (boundp 'emacs-version)                                                                    
         (< (aref emacs-version (1- (length emacs-version))) ?A)                                    
         (or (and (boundp 'epoch::version) epoch::version)                                          
             (string-lessp emacs-version "20")))                                                    
    (error "`utf-8-input.el' was compiled for Emacs 20 or later"))

(require 'quail)

(quail-define-package
 "utf-8-input"
 "utf-8 input"
 "[utf-8-input]" t
 "utf-8 input framework for Latin-1 Supplement, Latin Extended-A,
  Latin Extended-B, IPA Extensions, Spacing Modifier Letters,
  Combining Diacritical Marks, and Latin Extended Additional:
  cf. http://www.unicode.org/charts/

  Method uses postfix modifiers:

                    | postfix | examples
  ------------------+---------+-----------
   acute            |    '    | a' -> á
   double acute     |    ''   | o'' -> ő
   grave            |    `    | a` -> à
   double grave     |    ``   | o`` -> ȍ
   circumflex       |    ^    | a^ -> â
   circumflex below |    /^   | e/^ -> ḙ
   diaeresis        |    \"   | a\" -> ä
   tilde            |    ~    | a~ -> ã
   tilde below      |    /~   | i/~ -> ḭ
   macron           |    -    | a- -> ā
   line below       |    _    | k_ -> ḵ
   cedilla          |    /,   | c/, -> ç
   comma below      |    /,   | s/, -> ş
   hook             |    )    | z) -> ȥ
   ring above       |    /o   | a/o -> å
   ring below       |    _/o  | a_/o -> ḁ
   dot above        |    /.   | m/. -> ṁ
   middle dot       |    /m.  | l/m. -> ŀ
   dot below        |    /    | m/ -> ṃ
   breve            |    /u   | a/u -> ă
   inverted breve   |    /n   | a/n -> ȃ
   caron            |    /v   | k/v -> ǩ
   stroke           |    /-   | o/- -> ø
   combining        |   '-    | o'- -> ṓ 
                    |   `/u   | a`/u -> ằ
                    |   -\"   | U-\" -> Ǖ
                    |   /./   | s//. -> ṩ
   ligature         |         | ae/ -> æ
   sundries         |         | << -> «
                    |         | /rt -> √

"
 nil nil nil nil nil nil nil nil nil nil t )

(quail-define-rules

  ("dagger" ?†) ;; DAGGER
  ("ddagger" ?‡) ;; DOUBLE DAGGER
;; Latin-1 Supplement
;;  ("" ? ) ;; NO-BREAK SPACE
  ("!" ?¡) ;; INVERTED EXCLAMATION MARK
  ("|c" ?¢) ;; CENT SIGN
  ("$" ?£) ;; POUND SIGN
;;  ("" ?¤) ;; CURRENCY SIGN
;;  ("" ?¥) ;; YEN SIGN
;;  ("" ?¦) ;; BROKEN BAR
  ("\\S" ?§) ;; SECTION SIGN
;;  ("" ?¨) ;; DIAERESIS
  ("COPY" ?©) ;; COPYRIGHT SIGN
;;  ("" ?ª) ;; FEMININE ORDINAL INDICATOR
  ("<<" ?«) ;; LEFT-POINTING DOUBLE ANGLE QUOTATION MARK
;;  ("" ?¬) ;; NOT SIGN
;;  ("" ?­) ;; SOFT HYPHEN
  ("REG" ?®) ;; REGISTERED SIGN
  ("/-" ?¯) ;; MACRON
  ("/o" ?°) ;; DEGREE SIGN
;;  ("" ?±) ;; PLUS-MINUS SIGN
;;  ("" ?²) ;; SUPERSCRIPT TWO
;;  ("" ?³) ;; SUPERSCRIPT THREE
  ("/'" ?´) ;; ACUTE ACCENT
;;  ("" ?µ) ;; MICRO SIGN
  ("/P" ?¶) ;; PILCROW SIGN
  ("/m." ?·) ;; MIDDLE DOT
  ("/," ?¸) ;; CEDILLA
;;  ("" ?¹) ;; SUPERSCRIPT ONE
;;  ("" ?º) ;; MASCULINE ORDINAL INDICATOR
  (">>" ?») ;; RIGHT-POINTING DOUBLE ANGLE QUOTATION MARK
;;  ("" ?¼) ;; VULGAR FRACTION ONE QUARTER
;;  ("" ?½) ;; VULGAR FRACTION ONE HALF
;;  ("" ?¾) ;; VULGAR FRACTION THREE QUARTERS
  ("?" ?¿) ;; INVERTED QUESTION MARK
  ("A`" ?À) ;; LATIN CAPITAL LETTER A WITH GRAVE
  ("A'" ?Á) ;; LATIN CAPITAL LETTER A WITH ACUTE
  ("A^" ?Â) ;; LATIN CAPITAL LETTER A WITH CIRCUMFLEX
  ("A~" ?Ã) ;; LATIN CAPITAL LETTER A WITH TILDE
  ("A\"" ?Ä) ;; LATIN CAPITAL LETTER A WITH DIAERESIS
  ("A/o" ?Å) ;; LATIN CAPITAL LETTER A WITH RING ABOVE
  ("AE/" ?Æ) ;; LATIN CAPITAL LETTER AE
  ("C/," ?Ç) ;; LATIN CAPITAL LETTER C WITH CEDILLA
  ("E`" ?È) ;; LATIN CAPITAL LETTER E WITH GRAVE
  ("E'" ?É) ;; LATIN CAPITAL LETTER E WITH ACUTE
  ("E^" ?Ê) ;; LATIN CAPITAL LETTER E WITH CIRCUMFLEX
  ("E\"" ?Ë) ;; LATIN CAPITAL LETTER E WITH DIAERESIS
  ("I`" ?Ì) ;; LATIN CAPITAL LETTER I WITH GRAVE
  ("I'" ?Í) ;; LATIN CAPITAL LETTER I WITH ACUTE
  ("I^" ?Î) ;; LATIN CAPITAL LETTER I WITH CIRCUMFLEX
  ("I\"" ?Ï) ;; LATIN CAPITAL LETTER I WITH DIAERESIS
;;  ("" ?Ð) ;; LATIN CAPITAL LETTER ETH
  ("N~" ?Ñ) ;; LATIN CAPITAL LETTER N WITH TILDE
  ("O`" ?Ò) ;; LATIN CAPITAL LETTER O WITH GRAVE
  ("O'" ?Ó) ;; LATIN CAPITAL LETTER O WITH ACUTE
  ("O^" ?Ô) ;; LATIN CAPITAL LETTER O WITH CIRCUMFLEX
  ("O~" ?Õ) ;; LATIN CAPITAL LETTER O WITH TILDE
  ("O\"" ?Ö) ;; LATIN CAPITAL LETTER O WITH DIAERESIS
;;  ("" ?×) ;; MULTIPLICATION SIGN
  ("O/-" ?Ø) ;; LATIN CAPITAL LETTER O WITH STROKE
  ("U`" ?Ù) ;; LATIN CAPITAL LETTER U WITH GRAVE
  ("U'" ?Ú) ;; LATIN CAPITAL LETTER U WITH ACUTE
  ("U^" ?Û) ;; LATIN CAPITAL LETTER U WITH CIRCUMFLEX
  ("U\"" ?Ü) ;; LATIN CAPITAL LETTER U WITH DIAERESIS
  ("Y'" ?Ý) ;; LATIN CAPITAL LETTER Y WITH ACUTE
  ("|P" ?Þ) ;; LATIN CAPITAL LETTER THORN
  ("ss/" ?ß) ;; LATIN SMALL LETTER SHARP S
  ("a`" ?à) ;; LATIN SMALL LETTER A WITH GRAVE
  ("a'" ?á) ;; LATIN SMALL LETTER A WITH ACUTE
  ("a^" ?â) ;; LATIN SMALL LETTER A WITH CIRCUMFLEX
  ("a~" ?ã) ;; LATIN SMALL LETTER A WITH TILDE
  ("a\"" ?ä) ;; LATIN SMALL LETTER A WITH DIAERESIS
  ("a/o" ?å) ;; LATIN SMALL LETTER A WITH RING ABOVE
  ("ae/" ?æ) ;; LATIN SMALL LETTER AE
  ("c/," ?ç) ;; LATIN SMALL LETTER C WITH CEDILLA
  ("e`" ?è) ;; LATIN SMALL LETTER E WITH GRAVE
  ("e'" ?é) ;; LATIN SMALL LETTER E WITH ACUTE
  ("e^" ?ê) ;; LATIN SMALL LETTER E WITH CIRCUMFLEX
  ("e\"" ?ë) ;; LATIN SMALL LETTER E WITH DIAERESIS
  ("i`" ?ì) ;; LATIN SMALL LETTER I WITH GRAVE
  ("i'" ?í) ;; LATIN SMALL LETTER I WITH ACUTE
  ("i^" ?î) ;; LATIN SMALL LETTER I WITH CIRCUMFLEX
  ("i\"" ?ï) ;; LATIN SMALL LETTER I WITH DIAERESIS
;;  ("" ?ð) ;; LATIN SMALL LETTER ETH
;;  ("n~" ?ñ) ;; LATIN SMALL LETTER N WITH TILDE
  ("j;" ?ñ) ;; LATIN SMALL LETTER N WITH TILDE
  ("o`" ?ò) ;; LATIN SMALL LETTER O WITH GRAVE
  ("o'" ?ó) ;; LATIN SMALL LETTER O WITH ACUTE
  ("o^" ?ô) ;; LATIN SMALL LETTER O WITH CIRCUMFLEX
  ("o~" ?õ) ;; LATIN SMALL LETTER O WITH TILDE
  ("o\"" ?ö) ;; LATIN SMALL LETTER O WITH DIAERESIS
;;  ("" ?÷) ;; DIVISION SIGN
  ("o/-" ?ø) ;; LATIN SMALL LETTER O WITH STROKE
  ("u`" ?ù) ;; LATIN SMALL LETTER U WITH GRAVE
  ("u'" ?ú) ;; LATIN SMALL LETTER U WITH ACUTE
  ("u^" ?û) ;; LATIN SMALL LETTER U WITH CIRCUMFLEX
  ("u\"" ?ü) ;; LATIN SMALL LETTER U WITH DIAERESIS
  ("y'" ?ý) ;; LATIN SMALL LETTER Y WITH ACUTE
  ("|p" ?þ) ;; LATIN SMALL LETTER THORN
  ("y\"" ?ÿ) ;; LATIN SMALL LETTER Y WITH DIAERESIS

;; Latin Extended-A 
;;  ("A-" ?Ā) ;; LATIN CAPITAL LETTER A WITH MACRON
;;  ("a-" ?ā) ;; LATIN SMALL LETTER A WITH MACRON
  ("A;" ?Ā) ;; LATIN CAPITAL LETTER A WITH MACRON
  ("a;" ?ā) ;; LATIN SMALL LETTER A WITH MACRON
  ("A/u" ?Ă) ;; LATIN CAPITAL LETTER A WITH BREVE
  ("a/u" ?ă) ;; LATIN SMALL LETTER A WITH BREVE
;;  ("" ?Ą) ;; LATIN CAPITAL LETTER A WITH OGONEK
;;  ("" ?ą) ;; LATIN SMALL LETTER A WITH OGONEK
  ("C'" ?Ć) ;; LATIN CAPITAL LETTER C WITH ACUTE
  ("c'" ?ć) ;; LATIN SMALL LETTER C WITH ACUTE
  ("C^" ?Ĉ) ;; LATIN CAPITAL LETTER C WITH CIRCUMFLEX
  ("c^" ?ĉ) ;; LATIN SMALL LETTER C WITH CIRCUMFLEX
  ("C/." ?Ċ) ;; LATIN CAPITAL LETTER C WITH DOT ABOVE
  ("c/." ?ċ) ;; LATIN SMALL LETTER C WITH DOT ABOVE
  ("C/v" ?Č) ;; LATIN CAPITAL LETTER C WITH CARON
  ("c/v" ?č) ;; LATIN SMALL LETTER C WITH CARON
  ("D/v" ?Ď) ;; LATIN CAPITAL LETTER D WITH CARON
  ("d/v" ?ď) ;; LATIN SMALL LETTER D WITH CARON
  ("D/-" ?Đ) ;; LATIN CAPITAL LETTER D WITH STROKE
  ("d/-" ?đ) ;; LATIN SMALL LETTER D WITH STROKE
  ("E-" ?Ē) ;; LATIN CAPITAL LETTER E WITH MACRON
  ("e-" ?ē) ;; LATIN SMALL LETTER E WITH MACRON
  ("E/u" ?Ĕ) ;; LATIN CAPITAL LETTER E WITH BREVE
  ("e/u" ?ĕ) ;; LATIN SMALL LETTER E WITH BREVE
  ("E/." ?Ė) ;; LATIN CAPITAL LETTER E WITH DOT ABOVE
  ("e/." ?ė) ;; LATIN SMALL LETTER E WITH DOT ABOVE
;;  ("" ?Ę) ;; LATIN CAPITAL LETTER E WITH OGONEK
;;  ("" ?ę) ;; LATIN SMALL LETTER E WITH OGONEK
  ("E/v" ?Ě) ;; LATIN CAPITAL LETTER E WITH CARON
  ("e/v" ?ě) ;; LATIN SMALL LETTER E WITH CARON
  ("G^" ?Ĝ) ;; LATIN CAPITAL LETTER G WITH CIRCUMFLEX
  ("g^" ?ĝ) ;; LATIN SMALL LETTER G WITH CIRCUMFLEX
  ("G/u" ?Ğ) ;; LATIN CAPITAL LETTER G WITH BREVE
  ("g/u" ?ğ) ;; LATIN SMALL LETTER G WITH BREVE
  ("G/." ?Ġ) ;; LATIN CAPITAL LETTER G WITH DOT ABOVE
  ("g/." ?ġ) ;; LATIN SMALL LETTER G WITH DOT ABOVE
  ("G/," ?Ģ) ;; LATIN CAPITAL LETTER G WITH CEDILLA
  ("g/," ?ģ) ;; LATIN SMALL LETTER G WITH CEDILLA
  ("H^" ?Ĥ) ;; LATIN CAPITAL LETTER H WITH CIRCUMFLEX
  ("h^" ?ĥ) ;; LATIN SMALL LETTER H WITH CIRCUMFLEX
  ("H/-" ?Ħ) ;; LATIN CAPITAL LETTER H WITH STROKE
  ("h/-" ?ħ) ;; LATIN SMALL LETTER H WITH STROKE
  ("I~" ?Ĩ) ;; LATIN CAPITAL LETTER I WITH TILDE
  ("i~" ?ĩ) ;; LATIN SMALL LETTER I WITH TILDE
;;  ("I-" ?Ī) ;; LATIN CAPITAL LETTER I WITH MACRON
;;  ("i-" ?ī) ;; LATIN SMALL LETTER I WITH MACRON
  ("I;" ?Ī) ;; LATIN CAPITAL LETTER I WITH MACRON
  ("i;" ?ī) ;; LATIN SMALL LETTER I WITH MACRON
  ("I/u" ?Ĭ) ;; LATIN CAPITAL LETTER I WITH BREVE
  ("i/u" ?ĭ) ;; LATIN SMALL LETTER I WITH BREVE
;;  ("" ?Į) ;; LATIN CAPITAL LETTER I WITH OGONEK
;;  ("" ?į) ;; LATIN SMALL LETTER I WITH OGONEK
  ("I/." ?İ) ;; LATIN CAPITAL LETTER I WITH DOT ABOVE
  ("i/" ?ı) ;; LATIN SMALL LETTER DOTLESS I
;;  ("" ?Ĳ) ;; LATIN CAPITAL LIGATURE IJ
;;  ("" ?ĳ) ;; LATIN SMALL LIGATURE IJ
  ("J^" ?Ĵ) ;; LATIN CAPITAL LETTER J WITH CIRCUMFLEX
  ("j^" ?ĵ) ;; LATIN SMALL LETTER J WITH CIRCUMFLEX
  ("K/," ?Ķ) ;; LATIN CAPITAL LETTER K WITH CEDILLA
  ("k/," ?ķ) ;; LATIN SMALL LETTER K WITH CEDILLA
;;  ("" ?ĸ) ;; LATIN SMALL LETTER KRA
  ("L'" ?Ĺ) ;; LATIN CAPITAL LETTER L WITH ACUTE
  ("l'" ?ĺ) ;; LATIN SMALL LETTER L WITH ACUTE
  ("L/," ?Ļ) ;; LATIN CAPITAL LETTER L WITH CEDILLA
  ("l/," ?ļ) ;; LATIN SMALL LETTER L WITH CEDILLA
  ("L/v" ?Ľ) ;; LATIN CAPITAL LETTER L WITH CARON
  ("l/v" ?ľ) ;; LATIN SMALL LETTER L WITH CARON
  ("L/m." ?Ŀ) ;; LATIN CAPITAL LETTER L WITH MIDDLE DOT
  ("l/m." ?ŀ) ;; LATIN SMALL LETTER L WITH MIDDLE DOT
  ("L/-" ?Ł) ;; LATIN CAPITAL LETTER L WITH STROKE
  ("l/-" ?ł) ;; LATIN SMALL LETTER L WITH STROKE
  ("N'" ?Ń) ;; LATIN CAPITAL LETTER N WITH ACUTE
  ("n'" ?ń) ;; LATIN SMALL LETTER N WITH ACUTE
  ("N/," ?Ņ) ;; LATIN CAPITAL LETTER N WITH CEDILLA
  ("n/," ?ņ) ;; LATIN SMALL LETTER N WITH CEDILLA
  ("N/v" ?Ň) ;; LATIN CAPITAL LETTER N WITH CARON
  ("n/v" ?ň) ;; LATIN SMALL LETTER N WITH CARON
;;  ("" ?ŉ) ;; LATIN SMALL LETTER N PRECEDED BY APOSTROPHE
;;  ("" ?Ŋ) ;; LATIN CAPITAL LETTER ENG
;;  ("" ?ŋ) ;; LATIN SMALL LETTER ENG
  ("O-" ?Ō) ;; LATIN CAPITAL LETTER O WITH MACRON
  ("o-" ?ō) ;; LATIN SMALL LETTER O WITH MACRON
  ("O/u" ?Ŏ) ;; LATIN CAPITAL LETTER O WITH BREVE
  ("o/u" ?ŏ) ;; LATIN SMALL LETTER O WITH BREVE
  ("O''" ?Ő) ;; LATIN CAPITAL LETTER O WITH DOUBLE ACUTE
  ("o''" ?ő) ;; LATIN SMALL LETTER O WITH DOUBLE ACUTE
  ("OE/" ?Œ) ;; LATIN CAPITAL LIGATURE OE
  ("oe/" ?œ) ;; LATIN SMALL LIGATURE OE
  ("R'" ?Ŕ) ;; LATIN CAPITAL LETTER R WITH ACUTE
  ("r'" ?ŕ) ;; LATIN SMALL LETTER R WITH ACUTE
  ("R/," ?Ŗ) ;; LATIN CAPITAL LETTER R WITH CEDILLA
  ("r/," ?ŗ) ;; LATIN SMALL LETTER R WITH CEDILLA
  ("R/v" ?Ř) ;; LATIN CAPITAL LETTER R WITH CARON
  ("r/v" ?ř) ;; LATIN SMALL LETTER R WITH CARON
;;  ("S'" ?Ś) ;; LATIN CAPITAL LETTER S WITH ACUTE
;;  ("s'" ?ś) ;; LATIN SMALL LETTER S WITH ACUTE
  ("Z;" ?Ś) ;; LATIN CAPITAL LETTER S WITH ACUTE
  ("z;" ?ś) ;; LATIN SMALL LETTER S WITH ACUTE
  ("S^" ?Ŝ) ;; LATIN CAPITAL LETTER S WITH CIRCUMFLEX
  ("s^" ?ŝ) ;; LATIN SMALL LETTER S WITH CIRCUMFLEX
  ("S/," ?Ş) ;; LATIN CAPITAL LETTER S WITH CEDILLA
  ("s/," ?ş) ;; LATIN SMALL LETTER S WITH CEDILLA
  ("S/v" ?Š) ;; LATIN CAPITAL LETTER S WITH CARON
  ("s/v" ?š) ;; LATIN SMALL LETTER S WITH CARON
  ("T/," ?Ţ) ;; LATIN CAPITAL LETTER T WITH CEDILLA
  ("t/," ?ţ) ;; LATIN SMALL LETTER T WITH CEDILLA
  ("T/v" ?Ť) ;; LATIN CAPITAL LETTER T WITH CARON
  ("t/v" ?ť) ;; LATIN SMALL LETTER T WITH CARON
  ("T/-" ?Ŧ) ;; LATIN CAPITAL LETTER T WITH STROKE
  ("t/-" ?ŧ) ;; LATIN SMALL LETTER T WITH STROKE
  ("U~" ?Ũ) ;; LATIN CAPITAL LETTER U WITH TILDE
  ("u~" ?ũ) ;; LATIN SMALL LETTER U WITH TILDE
;;  ("U-" ?Ū) ;; LATIN CAPITAL LETTER U WITH MACRON
;;  ("u-" ?ū) ;; LATIN SMALL LETTER U WITH MACRON
  ("U;" ?Ū) ;; LATIN CAPITAL LETTER U WITH MACRON
  ("u;" ?ū) ;; LATIN SMALL LETTER U WITH MACRON
  ("U/u" ?Ŭ) ;; LATIN CAPITAL LETTER U WITH BREVE
  ("u/u" ?ŭ) ;; LATIN SMALL LETTER U WITH BREVE
  ("U/o" ?Ů) ;; LATIN CAPITAL LETTER U WITH RING ABOVE
  ("u/o" ?ů) ;; LATIN SMALL LETTER U WITH RING ABOVE
  ("U''" ?Ű) ;; LATIN CAPITAL LETTER U WITH DOUBLE ACUTE
  ("u''" ?ű) ;; LATIN SMALL LETTER U WITH DOUBLE ACUTE
;;  ("" ?Ų) ;; LATIN CAPITAL LETTER U WITH OGONEK
;;  ("" ?ų) ;; LATIN SMALL LETTER U WITH OGONEK
  ("W^" ?Ŵ) ;; LATIN CAPITAL LETTER W WITH CIRCUMFLEX
  ("w^" ?ŵ) ;; LATIN SMALL LETTER W WITH CIRCUMFLEX
  ("Y^" ?Ŷ) ;; LATIN CAPITAL LETTER Y WITH CIRCUMFLEX
  ("y^" ?ŷ) ;; LATIN SMALL LETTER Y WITH CIRCUMFLEX
  ("Y\"" ?Ÿ) ;; LATIN CAPITAL LETTER Y WITH DIAERESIS
  ("Z'" ?Ź) ;; LATIN CAPITAL LETTER Z WITH ACUTE
  ("z'" ?ź) ;; LATIN SMALL LETTER Z WITH ACUTE
  ("Z/." ?Ż) ;; LATIN CAPITAL LETTER Z WITH DOT ABOVE
  ("z/." ?ż) ;; LATIN SMALL LETTER Z WITH DOT ABOVE
  ("Z/v" ?Ž) ;; LATIN CAPITAL LETTER Z WITH CARON
  ("z/v" ?ž) ;; LATIN SMALL LETTER Z WITH CARON
;;  ("" ?ſ) ;; LATIN SMALL LETTER LONG S

;; Latin Extended-B
  ("b/-" ?ƀ) ;; LATIN SMALL LETTER B WITH STROKE
  ("B)" ?Ɓ) ;; LATIN CAPITAL LETTER B WITH HOOK
  ("B-" ?Ƃ) ;; LATIN CAPITAL LETTER B WITH TOPBAR
  ("b-" ?ƃ) ;; LATIN SMALL LETTER B WITH TOPBAR
;;  ("" ?Ƅ) ;; LATIN CAPITAL LETTER TONE SIX
;;  ("" ?ƅ) ;; LATIN SMALL LETTER TONE SIX
;;  ("" ?Ɔ) ;; LATIN CAPITAL LETTER OPEN O
  ("C)" ?Ƈ) ;; LATIN CAPITAL LETTER C WITH HOOK
  ("c)" ?ƈ) ;; LATIN SMALL LETTER C WITH HOOK
  ("D/-" ?Ɖ) ;; LATIN CAPITAL LETTER AFRICAN D
  ("D)" ?Ɗ) ;; LATIN CAPITAL LETTER D WITH HOOK
  ("D-" ?Ƌ) ;; LATIN CAPITAL LETTER D WITH TOPBAR
  ("d-" ?ƌ) ;; LATIN SMALL LETTER D WITH TOPBAR
  ("o/," ?ƍ) ;; LATIN SMALL LETTER TURNED DELTA
;;  ("" ?Ǝ) ;; LATIN CAPITAL LETTER REVERSED E
;;  ("" ?Ə) ;; LATIN CAPITAL LETTER SCHWA
;;  ("" ?Ɛ) ;; LATIN CAPITAL LETTER OPEN E
  ("F)" ?Ƒ) ;; LATIN CAPITAL LETTER F WITH HOOK
  ("f)" ?ƒ) ;; LATIN SMALL LETTER F WITH HOOK
  ("G)" ?Ɠ) ;; LATIN CAPITAL LETTER G WITH HOOK
;;  ("" ?Ɣ) ;; LATIN CAPITAL LETTER GAMMA
  ("h\\v" ?ƕ) ;; LATIN SMALL LETTER HV
;;  ("" ?Ɩ) ;; LATIN CAPITAL LETTER IOTA
  ("I/-" ?Ɨ) ;; LATIN CAPITAL LETTER I WITH STROKE
  ("K)" ?Ƙ) ;; LATIN CAPITAL LETTER K WITH HOOK
  ("k)" ?ƙ) ;; LATIN SMALL LETTER K WITH HOOK
;;  ("" ?ƚ) ;; LATIN SMALL LETTER L WITH BAR
;;  ("" ?ƛ) ;; LATIN SMALL LETTER LAMBDA WITH STROKE
;;  ("" ?Ɯ) ;; LATIN CAPITAL LETTER TURNED M
  ("N)" ?Ɲ) ;; LATIN CAPITAL LETTER N WITH LEFT HOOK
  ("n|" ?ƞ) ;; LATIN SMALL LETTER N WITH LONG RIGHT LEG
  ("O/~" ?Ɵ) ;; LATIN CAPITAL LETTER O WITH MIDDLE TILDE
;;  ("" ?Ơ) ;; LATIN CAPITAL LETTER O WITH HORN
;;  ("" ?ơ) ;; LATIN SMALL LETTER O WITH HORN
;;  ("" ?Ƣ) ;; LATIN CAPITAL LETTER OI
;;  ("" ?ƣ) ;; LATIN SMALL LETTER OI
  ("P)" ?Ƥ) ;; LATIN CAPITAL LETTER P WITH HOOK
  ("p)" ?ƥ) ;; LATIN SMALL LETTER P WITH HOOK
;;  ("" ?Ʀ) ;; LATIN LETTER YR
;;  ("" ?Ƨ) ;; LATIN CAPITAL LETTER TONE TWO
;;  ("" ?ƨ) ;; LATIN SMALL LETTER TONE TWO
;;  ("" ?Ʃ) ;; LATIN CAPITAL LETTER ESH
;;  ("" ?ƪ) ;; LATIN LETTER REVERSED ESH LOOP
  ("t)" ?ƫ) ;; LATIN SMALL LETTER T WITH PALATAL HOOK
  ("T)" ?Ƭ) ;; LATIN CAPITAL LETTER T WITH HOOK
  ("t(" ?ƭ) ;; LATIN SMALL LETTER T WITH HOOK
  ("T(" ?Ʈ) ;; LATIN CAPITAL LETTER T WITH RETROFLEX HOOK
;;  ("" ?Ư) ;; LATIN CAPITAL LETTER U WITH HORN
;;  ("" ?ư) ;; LATIN SMALL LETTER U WITH HORN
;;  ("" ?Ʊ) ;; LATIN CAPITAL LETTER UPSILON
  ("V)" ?Ʋ) ;; LATIN CAPITAL LETTER V WITH HOOK
  ("Y)" ?Ƴ) ;; LATIN CAPITAL LETTER Y WITH HOOK
  ("y)" ?ƴ) ;; LATIN SMALL LETTER Y WITH HOOK
  ("Z/-" ?Ƶ) ;; LATIN CAPITAL LETTER Z WITH STROKE
  ("z/-" ?ƶ) ;; LATIN SMALL LETTER Z WITH STROKE
;;  ("" ?Ʒ) ;; LATIN CAPITAL LETTER EZH
;;  ("" ?Ƹ) ;; LATIN CAPITAL LETTER EZH REVERSED
;;  ("" ?ƹ) ;; LATIN SMALL LETTER EZH REVERSED
;;  ("" ?ƺ) ;; LATIN SMALL LETTER EZH WITH TAIL
  ("2/-" ?ƻ) ;; LATIN LETTER TWO WITH STROKE
;;  ("" ?Ƽ) ;; LATIN CAPITAL LETTER TONE FIVE
;;  ("" ?ƽ) ;; LATIN SMALL LETTER TONE FIVE
;;  ("" ?ƾ) ;; LATIN LETTER INVERTED GLOTTAL STOP WITH STROKE
;;  ("" ?ƿ) ;; LATIN LETTER WYNN
  ("|" ?ǀ) ;; LATIN LETTER DENTAL CLICK
  ("||" ?ǁ) ;; LATIN LETTER LATERAL CLICK
  ("|=" ?ǂ) ;; LATIN LETTER ALVEOLAR CLICK
  ("!!" ?ǃ) ;; LATIN LETTER RETROFLEX CLICK
  ("DZ/v" ?Ǆ) ;; LATIN CAPITAL LETTER DZ WITH CARON
  ("Dz/v" ?ǅ) ;; LATIN CAPITAL LETTER D WITH SMALL LETTER Z WITH CARON
  ("dz/v" ?ǆ) ;; LATIN SMALL LETTER DZ WITH CARON
  ("LJ" ?Ǉ) ;; LATIN CAPITAL LETTER LJ
  ("Lj" ?ǈ) ;; LATIN CAPITAL LETTER L WITH SMALL LETTER J
  ("lj" ?ǉ) ;; LATIN SMALL LETTER LJ
  ("NJ" ?Ǌ) ;; LATIN CAPITAL LETTER NJ
  ("Nj" ?ǋ) ;; LATIN CAPITAL LETTER N WITH SMALL LETTER J
  ("nj" ?ǌ) ;; LATIN SMALL LETTER NJ
  ("A/v" ?Ǎ) ;; LATIN CAPITAL LETTER A WITH CARON
  ("a/v" ?ǎ) ;; LATIN SMALL LETTER A WITH CARON
  ("I/v" ?Ǐ) ;; LATIN CAPITAL LETTER I WITH CARON
  ("i/v" ?ǐ) ;; LATIN SMALL LETTER I WITH CARON
  ("O/v" ?Ǒ) ;; LATIN CAPITAL LETTER O WITH CARON
  ("o/v" ?ǒ) ;; LATIN SMALL LETTER O WITH CARON
  ("U/v" ?Ǔ) ;; LATIN CAPITAL LETTER U WITH CARON
  ("u/v" ?ǔ) ;; LATIN SMALL LETTER U WITH CARON
  ("U-\"" ?Ǖ) ;; LATIN CAPITAL LETTER U WITH DIAERESIS AND MACRON
  ("u-\"" ?ǖ) ;; LATIN SMALL LETTER U WITH DIAERESIS AND MACRON
  ("U'\"" ?Ǘ) ;; LATIN CAPITAL LETTER U WITH DIAERESIS AND ACUTE
  ("u'\"" ?ǘ) ;; LATIN SMALL LETTER U WITH DIAERESIS AND ACUTE
  ("U/v\"" ?Ǚ) ;; LATIN CAPITAL LETTER U WITH DIAERESIS AND CARON
  ("u/v\"" ?ǚ) ;; LATIN SMALL LETTER U WITH DIAERESIS AND CARON
  ("U`\"" ?Ǜ) ;; LATIN CAPITAL LETTER U WITH DIAERESIS AND GRAVE
  ("u`\"" ?ǜ) ;; LATIN SMALL LETTER U WITH DIAERESIS AND GRAVE
;;  ("" ?ǝ) ;; LATIN SMALL LETTER TURNED E
  ("A-\"" ?Ǟ) ;; LATIN CAPITAL LETTER A WITH DIAERESIS AND MACRON
  ("a-\"" ?ǟ) ;; LATIN SMALL LETTER A WITH DIAERESIS AND MACRON
  ("A-/." ?Ǡ) ;; LATIN CAPITAL LETTER A WITH DOT ABOVE AND MACRON
  ("a-/." ?ǡ) ;; LATIN SMALL LETTER A WITH DOT ABOVE AND MACRON
  ("AE/-" ?Ǣ) ;; LATIN CAPITAL LETTER AE WITH MACRON
  ("ae/-" ?ǣ) ;; LATIN SMALL LETTER AE WITH MACRON
  ("G/-" ?Ǥ) ;; LATIN CAPITAL LETTER G WITH STROKE
  ("g/-" ?ǥ) ;; LATIN SMALL LETTER G WITH STROKE
  ("G/v" ?Ǧ) ;; LATIN CAPITAL LETTER G WITH CARON
  ("g/v" ?ǧ) ;; LATIN SMALL LETTER G WITH CARON
  ("K/v" ?Ǩ) ;; LATIN CAPITAL LETTER K WITH CARON
  ("k/v" ?ǩ) ;; LATIN SMALL LETTER K WITH CARON
  ("O(" ?Ǫ) ;; LATIN CAPITAL LETTER O WITH OGONEK
  ("o(" ?ǫ) ;; LATIN SMALL LETTER O WITH OGONEK
  ("O-(" ?Ǭ) ;; LATIN CAPITAL LETTER O WITH OGONEK AND MACRON
  ("o-(" ?ǭ) ;; LATIN SMALL LETTER O WITH OGONEK AND MACRON
  ("3/v" ?Ǯ) ;; LATIN CAPITAL LETTER EZH WITH CARON
  ("3/v" ?ǯ) ;; LATIN SMALL LETTER EZH WITH CARON
  ("j/v" ?ǰ) ;; LATIN SMALL LETTER J WITH CARON
  ("DZ" ?Ǳ) ;; LATIN CAPITAL LETTER DZ
  ("Dz" ?ǲ) ;; LATIN CAPITAL LETTER D WITH SMALL LETTER Z
  ("dz" ?ǳ) ;; LATIN SMALL LETTER DZ
  ("G'" ?Ǵ) ;; LATIN CAPITAL LETTER G WITH ACUTE
  ("g'" ?ǵ) ;; LATIN SMALL LETTER G WITH ACUTE
;;  ("" ?Ƕ) ;; LATIN CAPITAL LETTER HWAIR
;;  ("" ?Ƿ) ;; LATIN CAPITAL LETTER WYNN
  ("N`" ?Ǹ) ;; LATIN CAPITAL LETTER N WITH GRAVE
  ("n`" ?ǹ) ;; LATIN SMALL LETTER N WITH GRAVE
  ("A'/o" ?Ǻ) ;; LATIN CAPITAL LETTER A WITH RING ABOVE AND ACUTE
  ("a'/o" ?ǻ) ;; LATIN SMALL LETTER A WITH RING ABOVE AND ACUTE
  ("AE/'" ?Ǽ) ;; LATIN CAPITAL LETTER AE WITH ACUTE
  ("ae/'" ?ǽ) ;; LATIN SMALL LETTER AE WITH ACUTE
  ("O/'" ?Ǿ) ;; LATIN CAPITAL LETTER O WITH STROKE AND ACUTE
  ("o/'" ?ǿ) ;; LATIN SMALL LETTER O WITH STROKE AND ACUTE
  ("A``" ?Ȁ) ;; LATIN CAPITAL LETTER A WITH DOUBLE GRAVE
  ("a``" ?ȁ) ;; LATIN SMALL LETTER A WITH DOUBLE GRAVE
  ("A/n" ?Ȃ) ;; LATIN CAPITAL LETTER A WITH INVERTED BREVE
  ("a/n" ?ȃ) ;; LATIN SMALL LETTER A WITH INVERTED BREVE
  ("E``" ?Ȅ) ;; LATIN CAPITAL LETTER E WITH DOUBLE GRAVE
  ("e``" ?ȅ) ;; LATIN SMALL LETTER E WITH DOUBLE GRAVE
  ("E/n" ?Ȇ) ;; LATIN CAPITAL LETTER E WITH INVERTED BREVE
  ("e/n" ?ȇ) ;; LATIN SMALL LETTER E WITH INVERTED BREVE
  ("I``" ?Ȉ) ;; LATIN CAPITAL LETTER I WITH DOUBLE GRAVE
  ("i``" ?ȉ) ;; LATIN SMALL LETTER I WITH DOUBLE GRAVE
  ("I/n" ?Ȋ) ;; LATIN CAPITAL LETTER I WITH INVERTED BREVE
  ("i/n" ?ȋ) ;; LATIN SMALL LETTER I WITH INVERTED BREVE
  ("O``" ?Ȍ) ;; LATIN CAPITAL LETTER O WITH DOUBLE GRAVE
  ("o``" ?ȍ) ;; LATIN SMALL LETTER O WITH DOUBLE GRAVE
  ("O/n" ?Ȏ) ;; LATIN CAPITAL LETTER O WITH INVERTED BREVE
  ("o/n" ?ȏ) ;; LATIN SMALL LETTER O WITH INVERTED BREVE
  ("R``" ?Ȑ) ;; LATIN CAPITAL LETTER R WITH DOUBLE GRAVE
  ("r``" ?ȑ) ;; LATIN SMALL LETTER R WITH DOUBLE GRAVE
  ("R^" ?Ȓ) ;; LATIN CAPITAL LETTER R WITH INVERTED BREVE
  ("r^" ?ȓ) ;; LATIN SMALL LETTER R WITH INVERTED BREVE
  ("U``" ?Ȕ) ;; LATIN CAPITAL LETTER U WITH DOUBLE GRAVE
  ("u``" ?ȕ) ;; LATIN SMALL LETTER U WITH DOUBLE GRAVE
  ("U/n" ?Ȗ) ;; LATIN CAPITAL LETTER U WITH INVERTED BREVE
  ("u/n" ?ȗ) ;; LATIN SMALL LETTER U WITH INVERTED BREVE
  ("S/," ?Ș) ;; LATIN CAPITAL LETTER S WITH COMMA BELOW
  ("s/," ?ș) ;; LATIN SMALL LETTER S WITH COMMA BELOW
  ("T/," ?Ț) ;; LATIN CAPITAL LETTER T WITH COMMA BELOW
  ("t/," ?ț) ;; LATIN SMALL LETTER T WITH COMMA BELOW
;;  ("" ?Ȝ) ;; LATIN CAPITAL LETTER YOGH
;;  ("" ?ȝ) ;; LATIN SMALL LETTER YOGH
  ("H/v" ?Ȟ) ;; LATIN CAPITAL LETTER H WITH CARON
  ("h/v" ?ȟ) ;; LATIN SMALL LETTER H WITH CARON
;; 0220 ?
;;  ("" ?Ȣ) ;; LATIN CAPITAL LETTER OU
;;  ("" ?ȣ) ;; LATIN SMALL LETTER OU
  ("Z)" ?Ȥ) ;; LATIN CAPITAL LETTER Z WITH HOOK
  ("z)" ?ȥ) ;; LATIN SMALL LETTER Z WITH HOOK
  ("A/." ?Ȧ) ;; LATIN CAPITAL LETTER A WITH DOT ABOVE
  ("a/." ?ȧ) ;; LATIN SMALL LETTER A WITH DOT ABOVE
  ("E/," ?Ȩ) ;; LATIN CAPITAL LETTER E WITH CEDILLA
  ("e/," ?ȩ) ;; LATIN SMALL LETTER E WITH CEDILLA
  ("O-\"" ?Ȫ) ;; LATIN CAPITAL LETTER O WITH DIAERESIS AND MACRON
  ("o-\"" ?ȫ) ;; LATIN SMALL LETTER O WITH DIAERESIS AND MACRON
  ("O-~" ?Ȭ) ;; LATIN CAPITAL LETTER O WITH TILDE AND MACRON
  ("o-~" ?ȭ) ;; LATIN SMALL LETTER O WITH TILDE AND MACRON
  ("O/." ?Ȯ) ;; LATIN CAPITAL LETTER O WITH DOT ABOVE
  ("o/." ?ȯ) ;; LATIN SMALL LETTER O WITH DOT ABOVE
  ("O-/." ?Ȱ) ;; LATIN CAPITAL LETTER O WITH DOT ABOVE AND MACRON
  ("o-/." ?ȱ) ;; LATIN SMALL LETTER O WITH DOT ABOVE AND MACRON
  ("Y-" ?Ȳ) ;; LATIN CAPITAL LETTER Y WITH MACRON
  ("y-" ?ȳ) ;; LATIN SMALL LETTER Y WITH MACRON

;; ;; IPA Extensions
;;  ("" ?ɐ) ;; LATIN SMALL LETTER TURNED A
;;  ("" ?ɑ) ;; LATIN SMALL LETTER ALPHA
;;  ("" ?ɒ) ;; LATIN SMALL LETTER TURNED ALPHA
;;  ("" ?ɓ) ;; LATIN SMALL LETTER B WITH HOOK
;;  ("" ?ɔ) ;; LATIN SMALL LETTER OPEN O
;;  ("" ?ɕ) ;; LATIN SMALL LETTER C WITH CURL
;;  ("" ?ɖ) ;; LATIN SMALL LETTER D WITH TAIL
;;  ("" ?ɗ) ;; LATIN SMALL LETTER D WITH HOOK
;;  ("" ?ɘ) ;; LATIN SMALL LETTER REVERSED E
;;  ("" ?ə) ;; LATIN SMALL LETTER SCHWA
;;  ("" ?ɚ) ;; LATIN SMALL LETTER SCHWA WITH HOOK
;;  ("" ?ɛ) ;; LATIN SMALL LETTER OPEN E
;;  ("" ?ɜ) ;; LATIN SMALL LETTER REVERSED OPEN E
;;  ("" ?ɝ) ;; LATIN SMALL LETTER REVERSED OPEN E WITH HOOK
;;  ("" ?ɞ) ;; LATIN SMALL LETTER CLOSED REVERSED OPEN E
;;  ("" ?ɟ) ;; LATIN SMALL LETTER DOTLESS J WITH STROKE
;;  ("" ?ɠ) ;; LATIN SMALL LETTER G WITH HOOK
;;  ("" ?ɡ) ;; LATIN SMALL LETTER SCRIPT G
;;  ("" ?ɢ) ;; LATIN LETTER SMALL CAPITAL G
;;  ("" ?ɣ) ;; LATIN SMALL LETTER GAMMA
;;  ("" ?ɤ) ;; LATIN SMALL LETTER RAMS HORN
;;  ("" ?ɥ) ;; LATIN SMALL LETTER TURNED H
;;  ("" ?ɦ) ;; LATIN SMALL LETTER H WITH HOOK
;;  ("" ?ɧ) ;; LATIN SMALL LETTER HENG WITH HOOK
;;  ("" ?ɨ) ;; LATIN SMALL LETTER I WITH STROKE
;;  ("" ?ɩ) ;; LATIN SMALL LETTER IOTA
;;  ("" ?ɪ) ;; LATIN LETTER SMALL CAPITAL I
;;  ("" ?ɫ) ;; LATIN SMALL LETTER L WITH MIDDLE TILDE
;;  ("" ?ɬ) ;; LATIN SMALL LETTER L WITH BELT
;;  ("" ?ɭ) ;; LATIN SMALL LETTER L WITH RETROFLEX HOOK
;;  ("" ?ɮ) ;; LATIN SMALL LETTER LEZH
;;  ("" ?ɯ) ;; LATIN SMALL LETTER TURNED M
;;  ("" ?ɰ) ;; LATIN SMALL LETTER TURNED M WITH LONG LEG
;;  ("" ?ɱ) ;; LATIN SMALL LETTER M WITH HOOK
;;  ("" ?ɲ) ;; LATIN SMALL LETTER N WITH LEFT HOOK
;;  ("" ?ɳ) ;; LATIN SMALL LETTER N WITH RETROFLEX HOOK
;;  ("" ?ɴ) ;; LATIN LETTER SMALL CAPITAL N
;;  ("" ?ɵ) ;; LATIN SMALL LETTER BARRED O
;;  ("" ?ɶ) ;; LATIN LETTER SMALL CAPITAL OE
;;  ("" ?ɷ) ;; LATIN SMALL LETTER CLOSED OMEGA
;;  ("" ?ɸ) ;; LATIN SMALL LETTER PHI
;;  ("" ?ɹ) ;; LATIN SMALL LETTER TURNED R
;;  ("" ?ɺ) ;; LATIN SMALL LETTER TURNED R WITH LONG LEG
;;  ("" ?ɻ) ;; LATIN SMALL LETTER TURNED R WITH HOOK
;;  ("" ?ɼ) ;; LATIN SMALL LETTER R WITH LONG LEG
;;  ("" ?ɽ) ;; LATIN SMALL LETTER R WITH TAIL
;;  ("" ?ɾ) ;; LATIN SMALL LETTER R WITH FISHHOOK
;;  ("" ?ɿ) ;; LATIN SMALL LETTER REVERSED R WITH FISHHOOK
;;  ("" ?ʀ) ;; LATIN LETTER SMALL CAPITAL R
;;  ("" ?ʁ) ;; LATIN LETTER SMALL CAPITAL INVERTED R
;;  ("" ?ʂ) ;; LATIN SMALL LETTER S WITH HOOK
;;  ("" ?ʃ) ;; LATIN SMALL LETTER ESH
;;  ("" ?ʄ) ;; LATIN SMALL LETTER DOTLESS J WITH STROKE AND HOOK
;;  ("" ?ʅ) ;; LATIN SMALL LETTER SQUAT REVERSED ESH
;;  ("" ?ʆ) ;; LATIN SMALL LETTER ESH WITH CURL
;;  ("" ?ʇ) ;; LATIN SMALL LETTER TURNED T
;;  ("" ?ʈ) ;; LATIN SMALL LETTER T WITH RETROFLEX HOOK
;;  ("" ?ʉ) ;; LATIN SMALL LETTER U BAR
;;  ("" ?ʊ) ;; LATIN SMALL LETTER UPSILON
;;  ("" ?ʋ) ;; LATIN SMALL LETTER V WITH HOOK
;;  ("" ?ʌ) ;; LATIN SMALL LETTER TURNED V
;;  ("" ?ʍ) ;; LATIN SMALL LETTER TURNED W
;;  ("" ?ʎ) ;; LATIN SMALL LETTER TURNED Y
;;  ("" ?ʏ) ;; LATIN LETTER SMALL CAPITAL Y
;;  ("" ?ʐ) ;; LATIN SMALL LETTER Z WITH RETROFLEX HOOK
;;  ("" ?ʑ) ;; LATIN SMALL LETTER Z WITH CURL
;;  ("" ?ʒ) ;; LATIN SMALL LETTER EZH
;;  ("" ?ʓ) ;; LATIN SMALL LETTER EZH WITH CURL
;;  ("" ?ʔ) ;; LATIN LETTER GLOTTAL STOP
;;  ("" ?ʕ) ;; LATIN LETTER PHARYNGEAL VOICED FRICATIVE
;;  ("" ?ʖ) ;; LATIN LETTER INVERTED GLOTTAL STOP
;;  ("" ?ʗ) ;; LATIN LETTER STRETCHED C
;;  ("" ?ʘ) ;; LATIN LETTER BILABIAL CLICK
;;  ("" ?ʙ) ;; LATIN LETTER SMALL CAPITAL B
;;  ("" ?ʚ) ;; LATIN SMALL LETTER CLOSED OPEN E
;;  ("" ?ʛ) ;; LATIN LETTER SMALL CAPITAL G WITH HOOK
;;  ("" ?ʜ) ;; LATIN LETTER SMALL CAPITAL H
;;  ("" ?ʝ) ;; LATIN SMALL LETTER J WITH CROSSED-TAIL
;;  ("" ?ʞ) ;; LATIN SMALL LETTER TURNED K
;;  ("" ?ʟ) ;; LATIN LETTER SMALL CAPITAL L
;;  ("" ?ʠ) ;; LATIN SMALL LETTER Q WITH HOOK
;;  ("" ?ʡ) ;; LATIN LETTER GLOTTAL STOP WITH STROKE
;;  ("" ?ʢ) ;; LATIN LETTER REVERSED GLOTTAL STOP WITH STROKE
;;  ("" ?ʣ) ;; LATIN SMALL LETTER DZ DIGRAPH
;;  ("" ?ʤ) ;; LATIN SMALL LETTER DEZH DIGRAPH
;;  ("" ?ʥ) ;; LATIN SMALL LETTER DZ DIGRAPH WITH CURL
;;  ("" ?ʦ) ;; LATIN SMALL LETTER TS DIGRAPH
;;  ("" ?ʧ) ;; LATIN SMALL LETTER TESH DIGRAPH
;;  ("" ?ʨ) ;; LATIN SMALL LETTER TC DIGRAPH WITH CURL
;;  ("" ?ʩ) ;; LATIN SMALL LETTER FENG DIGRAPH
;;  ("" ?ʪ) ;; LATIN SMALL LETTER LS DIGRAPH
;;  ("" ?ʫ) ;; LATIN SMALL LETTER LZ DIGRAPH
;;  ("" ?ʬ) ;; LATIN LETTER BILABIAL PERCUSSIVE
;;  ("" ?ʭ) ;; LATIN LETTER BIDENTAL PERCUSSIVE

;; ;; Spacing Modifier Letters
;;  ("" ?ʰ) ;; MODIFIER LETTER SMALL H
;;  ("" ?ʱ) ;; MODIFIER LETTER SMALL H WITH HOOK
;;  ("" ?ʲ) ;; MODIFIER LETTER SMALL J
;;  ("" ?ʳ) ;; MODIFIER LETTER SMALL R
;;  ("" ?ʴ) ;; MODIFIER LETTER SMALL TURNED R
;;  ("" ?ʵ) ;; MODIFIER LETTER SMALL TURNED R WITH HOOK
;;  ("" ?ʶ) ;; MODIFIER LETTER SMALL CAPITAL INVERTED R
;;  ("" ?ʷ) ;; MODIFIER LETTER SMALL W
;;  ("" ?ʸ) ;; MODIFIER LETTER SMALL Y
;;  ("" ?ʹ) ;; MODIFIER LETTER PRIME
;;  ("" ?ʺ) ;; MODIFIER LETTER DOUBLE PRIME
;;  ("" ?ʻ) ;; MODIFIER LETTER TURNED COMMA
;;  ("" ?ʼ) ;; MODIFIER LETTER APOSTROPHE
;;  ("" ?ʽ) ;; MODIFIER LETTER REVERSED COMMA
;;  ("" ?ʾ) ;; MODIFIER LETTER RIGHT HALF RING
;;  ("" ?ʿ) ;; MODIFIER LETTER LEFT HALF RING
;;  ("" ?ˀ) ;; MODIFIER LETTER GLOTTAL STOP
;;  ("" ?ˁ) ;; MODIFIER LETTER REVERSED GLOTTAL STOP
;;  ("" ?˂) ;; MODIFIER LETTER LEFT ARROWHEAD
;;  ("" ?˃) ;; MODIFIER LETTER RIGHT ARROWHEAD
;;  ("" ?˄) ;; MODIFIER LETTER UP ARROWHEAD
;;  ("" ?˅) ;; MODIFIER LETTER DOWN ARROWHEAD
;;  ("" ?ˆ) ;; MODIFIER LETTER CIRCUMFLEX ACCENT
;;  ("" ?ˇ) ;; CARON
;;  ("" ?ˈ) ;; MODIFIER LETTER VERTICAL LINE
;;  ("" ?ˉ) ;; MODIFIER LETTER MACRON
;;  ("" ?ˊ) ;; MODIFIER LETTER ACUTE ACCENT
;;  ("" ?ˋ) ;; MODIFIER LETTER GRAVE ACCENT
;;  ("" ?ˌ) ;; MODIFIER LETTER LOW VERTICAL LINE
;;  ("" ?ˍ) ;; MODIFIER LETTER LOW MACRON
;;  ("" ?ˎ) ;; MODIFIER LETTER LOW GRAVE ACCENT
;;  ("" ?ˏ) ;; MODIFIER LETTER LOW ACUTE ACCENT
;;  ("" ?ː) ;; MODIFIER LETTER TRIANGULAR COLON
;;  ("" ?ˑ) ;; MODIFIER LETTER HALF TRIANGULAR COLON
;;  ("" ?˒) ;; MODIFIER LETTER CENTRED RIGHT HALF RING
;;  ("" ?˓) ;; MODIFIER LETTER CENTRED LEFT HALF RING
;;  ("" ?˔) ;; MODIFIER LETTER UP TACK
;;  ("" ?˕) ;; MODIFIER LETTER DOWN TACK
;;  ("" ?˖) ;; MODIFIER LETTER PLUS SIGN
;;  ("" ?˗) ;; MODIFIER LETTER MINUS SIGN
;;  ("" ?˘) ;; BREVE
;;  ("" ?˙) ;; DOT ABOVE
;;  ("" ?˚) ;; RING ABOVE
;;  ("" ?˛) ;; OGONEK
;;  ("" ?˜) ;; SMALL TILDE
;;  ("" ?˝) ;; DOUBLE ACUTE ACCENT
;;  ("" ?˞) ;; MODIFIER LETTER RHOTIC HOOK
;;  ("" ?˟) ;; MODIFIER LETTER CROSS ACCENT
;;  ("" ?ˠ) ;; MODIFIER LETTER SMALL GAMMA
;;  ("" ?ˡ) ;; MODIFIER LETTER SMALL L
;;  ("" ?ˢ) ;; MODIFIER LETTER SMALL S
;;  ("" ?ˣ) ;; MODIFIER LETTER SMALL X
;;  ("" ?ˤ) ;; MODIFIER LETTER SMALL REVERSED GLOTTAL STOP
;;  ("" ?˥) ;; MODIFIER LETTER EXTRA-HIGH TONE BAR
;;  ("" ?˦) ;; MODIFIER LETTER HIGH TONE BAR
;;  ("" ?˧) ;; MODIFIER LETTER MID TONE BAR
;;  ("" ?˨) ;; MODIFIER LETTER LOW TONE BAR
;;  ("" ?˩) ;; MODIFIER LETTER EXTRA-LOW TONE BAR
;;  ("" ?˪) ;; MODIFIER LETTER YIN DEPARTING TONE MARK
;;  ("" ?˫) ;; MODIFIER LETTER YANG DEPARTING TONE MARK
;;  ("" ?ˬ) ;; MODIFIER LETTER VOICING
;;  ("" ?˭) ;; MODIFIER LETTER UNASPIRATED
;;  ("" ?ˮ) ;; MODIFIER LETTER DOUBLE APOSTROPHE

;; ;; Combining Diacritical Marks
;;  ("" ?̀) ;; COMBINING GRAVE ACCENT
;;  ("" ?́) ;; COMBINING ACUTE ACCENT
;;  ("" ?̂) ;; COMBINING CIRCUMFLEX ACCENT
;;  ("" ?̃) ;; COMBINING TILDE
;;  ("" ?̄) ;; COMBINING MACRON
;;  ("" ?̅) ;; COMBINING OVERLINE
;;  ("" ?̆) ;; COMBINING BREVE
;;  ("" ?̇) ;; COMBINING DOT ABOVE
;;  ("" ?̈) ;; COMBINING DIAERESIS
;;  ("" ?̉) ;; COMBINING HOOK ABOVE
;;  ("" ?̊) ;; COMBINING RING ABOVE
;;  ("" ?̋) ;; COMBINING DOUBLE ACUTE ACCENT
;;  ("" ?̌) ;; COMBINING CARON
;;  ("" ?̍) ;; COMBINING VERTICAL LINE ABOVE
;;  ("" ?̎) ;; COMBINING DOUBLE VERTICAL LINE ABOVE
;;  ("" ?̏) ;; COMBINING DOUBLE GRAVE ACCENT
;;  ("" ?̐) ;; COMBINING CANDRABINDU
;;  ("" ?̑) ;; COMBINING INVERTED BREVE
;;  ("" ?̒) ;; COMBINING TURNED COMMA ABOVE
;;  ("" ?̓) ;; COMBINING COMMA ABOVE
;;  ("" ?̔) ;; COMBINING REVERSED COMMA ABOVE
;;  ("" ?̕) ;; COMBINING COMMA ABOVE RIGHT
;;  ("" ?̖) ;; COMBINING GRAVE ACCENT BELOW
;;  ("" ?̗) ;; COMBINING ACUTE ACCENT BELOW
;;  ("" ?̘) ;; COMBINING LEFT TACK BELOW
;;  ("" ?̙) ;; COMBINING RIGHT TACK BELOW
;;  ("" ?̚) ;; COMBINING LEFT ANGLE ABOVE
;;  ("" ?̛) ;; COMBINING HORN
;;  ("" ?̜) ;; COMBINING LEFT HALF RING BELOW
;;  ("" ?̝) ;; COMBINING UP TACK BELOW
;;  ("" ?̞) ;; COMBINING DOWN TACK BELOW
;;  ("" ?̟) ;; COMBINING PLUS SIGN BELOW
;;  ("" ?̠) ;; COMBINING MINUS SIGN BELOW
;;  ("" ?̡) ;; COMBINING PALATALIZED HOOK BELOW
;;  ("" ?̢) ;; COMBINING RETROFLEX HOOK BELOW
;;  ("" ?̣) ;; COMBINING DOT BELOW
;;  ("" ?̤) ;; COMBINING DIAERESIS BELOW
;;  ("" ?̥) ;; COMBINING RING BELOW
;;  ("" ?̦) ;; COMBINING COMMA BELOW
;;  ("" ?̧) ;; COMBINING CEDILLA
;;  ("" ?̨) ;; COMBINING OGONEK
;;  ("" ?̩) ;; COMBINING VERTICAL LINE BELOW
;;  ("" ?̪) ;; COMBINING BRIDGE BELOW
;;  ("" ?̫) ;; COMBINING INVERTED DOUBLE ARCH BELOW
;;  ("" ?̬) ;; COMBINING CARON BELOW
;;  ("" ?̭) ;; COMBINING CIRCUMFLEX ACCENT BELOW
;;  ("" ?̮) ;; COMBINING BREVE BELOW
;;  ("" ?̯) ;; COMBINING INVERTED BREVE BELOW
;;  ("" ?̰) ;; COMBINING TILDE BELOW
;;  ("" ?̱) ;; COMBINING MACRON BELOW
;;  ("" ?̲) ;; COMBINING LOW LINE
;;  ("" ?̳) ;; COMBINING DOUBLE LOW LINE
;;  ("" ?̴) ;; COMBINING TILDE OVERLAY
;;  ("" ?̵) ;; COMBINING SHORT STROKE OVERLAY
;;  ("" ?̶) ;; COMBINING LONG STROKE OVERLAY
;;  ("" ?̷) ;; COMBINING SHORT SOLIDUS OVERLAY
;;  ("" ?̸) ;; COMBINING LONG SOLIDUS OVERLAY
;;  ("" ?̹) ;; COMBINING RIGHT HALF RING BELOW
;;  ("" ?̺) ;; COMBINING INVERTED BRIDGE BELOW
;;  ("" ?̻) ;; COMBINING SQUARE BELOW
;;  ("" ?̼) ;; COMBINING SEAGULL BELOW
;;  ("" ?̽) ;; COMBINING X ABOVE
;;  ("" ?̾) ;; COMBINING VERTICAL TILDE
;;  ("" ?̿) ;; COMBINING DOUBLE OVERLINE
;;  ("" ?̀) ;; COMBINING GRAVE TONE MARK
;;  ("" ?́) ;; COMBINING ACUTE TONE MARK
;;  ("" ?͂) ;; COMBINING GREEK PERISPOMENI
;;  ("" ?̓) ;; COMBINING GREEK KORONIS
;;  ("" ?̈́) ;; COMBINING GREEK DIALYTIKA TONOS
;;  ("" ?ͅ) ;; COMBINING GREEK YPOGEGRAMMENI
;;  ("" ?͆) ;; COMBINING BRIDGE ABOVE
;;  ("" ?͇) ;; COMBINING EQUALS SIGN BELOW
;;  ("" ?͈) ;; COMBINING DOUBLE VERTICAL LINE BELOW
;;  ("" ?͉) ;; COMBINING LEFT ANGLE BELOW
;;  ("" ?͊) ;; COMBINING NOT TILDE ABOVE
;;  ("" ?͋) ;; COMBINING HOMOTHETIC ABOVE
;;  ("" ?͌) ;; COMBINING ALMOST EQUAL TO ABOVE
;;  ("" ?͍) ;; COMBINING LEFT RIGHT ARROW BELOW
;;  ("" ?͎) ;; COMBINING UPWARDS ARROW BELOW
;;  ("" ?͠) ;; COMBINING DOUBLE TILDE
;;  ("" ?͡) ;; COMBINING DOUBLE INVERTED BREVE
;;  ("" ?͢) ;; COMBINING DOUBLE RIGHTWARDS ARROW BELOW

;; Latin Extended Additional
  ("A_/o" ?Ḁ) ;; LATIN CAPITAL LETTER A WITH RING BELOW
  ("a_/o" ?ḁ) ;; LATIN SMALL LETTER A WITH RING BELOW
  ("B/." ?Ḃ) ;; LATIN CAPITAL LETTER B WITH DOT ABOVE
  ("b/." ?ḃ) ;; LATIN SMALL LETTER B WITH DOT ABOVE
  ("B/" ?Ḅ) ;; LATIN CAPITAL LETTER B WITH DOT BELOW
  ("b/" ?ḅ) ;; LATIN SMALL LETTER B WITH DOT BELOW
  ("B_" ?Ḇ) ;; LATIN CAPITAL LETTER B WITH LINE BELOW
  ("b_" ?ḇ) ;; LATIN SMALL LETTER B WITH LINE BELOW
  ("C'/," ?Ḉ) ;; LATIN CAPITAL LETTER C WITH CEDILLA AND ACUTE
  ("c'/," ?ḉ) ;; LATIN SMALL LETTER C WITH CEDILLA AND ACUTE
  ("D/." ?Ḋ) ;; LATIN CAPITAL LETTER D WITH DOT ABOVE
  ("d/." ?ḋ) ;; LATIN SMALL LETTER D WITH DOT ABOVE
;;  ("D/" ?Ḍ) ;; LATIN CAPITAL LETTER D WITH DOT BELOW
;;  ("d/" ?ḍ) ;; LATIN SMALL LETTER D WITH DOT BELOW
  ("D;" ?Ḍ) ;; LATIN CAPITAL LETTER D WITH DOT BELOW
  ("d;" ?ḍ) ;; LATIN SMALL LETTER D WITH DOT BELOW
  ("D_" ?Ḏ) ;; LATIN CAPITAL LETTER D WITH LINE BELOW
  ("d_" ?ḏ) ;; LATIN SMALL LETTER D WITH LINE BELOW
  ("D/," ?Ḑ) ;; LATIN CAPITAL LETTER D WITH CEDILLA
  ("d/," ?ḑ) ;; LATIN SMALL LETTER D WITH CEDILLA
  ("D/^" ?Ḓ) ;; LATIN CAPITAL LETTER D WITH CIRCUMFLEX BELOW
  ("d/^" ?ḓ) ;; LATIN SMALL LETTER D WITH CIRCUMFLEX BELOW
  ("E`-" ?Ḕ) ;; LATIN CAPITAL LETTER E WITH MACRON AND GRAVE
  ("e`-" ?ḕ) ;; LATIN SMALL LETTER E WITH MACRON AND GRAVE
  ("E'-" ?Ḗ) ;; LATIN CAPITAL LETTER E WITH MACRON AND ACUTE
  ("e'-" ?ḗ) ;; LATIN SMALL LETTER E WITH MACRON AND ACUTE
  ("E/^" ?Ḙ) ;; LATIN CAPITAL LETTER E WITH CIRCUMFLEX BELOW
  ("e/^" ?ḙ) ;; LATIN SMALL LETTER E WITH CIRCUMFLEX BELOW
  ("E/~" ?Ḛ) ;; LATIN CAPITAL LETTER E WITH TILDE BELOW
  ("e/~" ?ḛ) ;; LATIN SMALL LETTER E WITH TILDE BELOW
  ("E/u/," ?Ḝ) ;; LATIN CAPITAL LETTER E WITH CEDILLA AND BREVE
  ("e/u/," ?ḝ) ;; LATIN SMALL LETTER E WITH CEDILLA AND BREVE
  ("F/." ?Ḟ) ;; LATIN CAPITAL LETTER F WITH DOT ABOVE
  ("f/." ?ḟ) ;; LATIN SMALL LETTER F WITH DOT ABOVE
  ("G-" ?Ḡ) ;; LATIN CAPITAL LETTER G WITH MACRON
  ("g-" ?ḡ) ;; LATIN SMALL LETTER G WITH MACRON
  ("H/." ?Ḣ) ;; LATIN CAPITAL LETTER H WITH DOT ABOVE
  ("h/." ?ḣ) ;; LATIN SMALL LETTER H WITH DOT ABOVE
;;  ("H/" ?Ḥ) ;; LATIN CAPITAL LETTER H WITH DOT BELOW
;;  ("h/" ?ḥ) ;; LATIN SMALL LETTER H WITH DOT BELOW
  ("H;" ?Ḥ) ;; LATIN CAPITAL LETTER H WITH DOT BELOW
  ("h;" ?ḥ) ;; LATIN SMALL LETTER H WITH DOT BELOW
  ("H\"" ?Ḧ) ;; LATIN CAPITAL LETTER H WITH DIAERESIS
  ("h\"" ?ḧ) ;; LATIN SMALL LETTER H WITH DIAERESIS
  ("H/," ?Ḩ) ;; LATIN CAPITAL LETTER H WITH CEDILLA
  ("h/," ?ḩ) ;; LATIN SMALL LETTER H WITH CEDILLA
  ("H_/u" ?Ḫ) ;; LATIN CAPITAL LETTER H WITH BREVE BELOW
  ("h_/u" ?ḫ) ;; LATIN SMALL LETTER H WITH BREVE BELOW
  ("I/~" ?Ḭ) ;; LATIN CAPITAL LETTER I WITH TILDE BELOW
  ("i/~" ?ḭ) ;; LATIN SMALL LETTER I WITH TILDE BELOW
  ("I'\"" ?Ḯ) ;; LATIN CAPITAL LETTER I WITH DIAERESIS AND ACUTE
  ("i'\"" ?ḯ) ;; LATIN SMALL LETTER I WITH DIAERESIS AND ACUTE
  ("K'" ?Ḱ) ;; LATIN CAPITAL LETTER K WITH ACUTE
  ("k'" ?ḱ) ;; LATIN SMALL LETTER K WITH ACUTE
  ("K/" ?Ḳ) ;; LATIN CAPITAL LETTER K WITH DOT BELOW
  ("k/" ?ḳ) ;; LATIN SMALL LETTER K WITH DOT BELOW
  ("K_" ?Ḵ) ;; LATIN CAPITAL LETTER K WITH LINE BELOW
  ("k_" ?ḵ) ;; LATIN SMALL LETTER K WITH LINE BELOW
;;  ("L/" ?Ḷ) ;; LATIN CAPITAL LETTER L WITH DOT BELOW
;;  ("l/" ?ḷ) ;; LATIN SMALL LETTER L WITH DOT BELOW
  ("L;" ?Ḷ) ;; LATIN CAPITAL LETTER L WITH DOT BELOW
  ("l;" ?ḷ) ;; LATIN SMALL LETTER L WITH DOT BELOW
  ("L-/" ?Ḹ) ;; LATIN CAPITAL LETTER L WITH DOT BELOW AND MACRON
  ("l-/" ?ḹ) ;; LATIN SMALL LETTER L WITH DOT BELOW AND MACRON
  ("L_" ?Ḻ) ;; LATIN CAPITAL LETTER L WITH LINE BELOW
  ("l_" ?ḻ) ;; LATIN SMALL LETTER L WITH LINE BELOW
  ("L/^" ?Ḽ) ;; LATIN CAPITAL LETTER L WITH CIRCUMFLEX BELOW
  ("l/^" ?ḽ) ;; LATIN SMALL LETTER L WITH CIRCUMFLEX BELOW
  ("M'" ?Ḿ) ;; LATIN CAPITAL LETTER M WITH ACUTE
  ("m'" ?ḿ) ;; LATIN SMALL LETTER M WITH ACUTE
;;  ("M/" ?Ṁ) ;; LATIN CAPITAL LETTER M WITH DOT ABOVE
;;  ("m/" ?ṁ) ;; LATIN SMALL LETTER M WITH DOT ABOVE
  ("M;" ?Ṁ) ;; LATIN CAPITAL LETTER M WITH DOT ABOVE
  ("m;" ?ṁ) ;; LATIN SMALL LETTER M WITH DOT ABOVE
  ("M/." ?Ṃ) ;; LATIN CAPITAL LETTER M WITH DOT BELOW
  ("m/." ?ṃ) ;; LATIN SMALL LETTER M WITH DOT BELOW
;;  ("N/." ?Ṅ) ;; LATIN CAPITAL LETTER N WITH DOT ABOVE
;;  ("n/." ?ṅ) ;; LATIN SMALL LETTER N WITH DOT ABOVE
  ("G;" ?Ṅ) ;; LATIN CAPITAL LETTER N WITH DOT ABOVE
  ("g;" ?ṅ) ;; LATIN SMALL LETTER N WITH DOT ABOVE
;;  ("N/" ?Ṇ) ;; LATIN CAPITAL LETTER N WITH DOT BELOW
;;  ("n/" ?ṇ) ;; LATIN SMALL LETTER N WITH DOT BELOW
  ("N;" ?Ṇ) ;; LATIN CAPITAL LETTER N WITH DOT BELOW
  ("n;" ?ṇ) ;; LATIN SMALL LETTER N WITH DOT BELOW
  ("N_" ?Ṉ) ;; LATIN CAPITAL LETTER N WITH LINE BELOW
  ("n_" ?ṉ) ;; LATIN SMALL LETTER N WITH LINE BELOW
  ("N/^" ?Ṋ) ;; LATIN CAPITAL LETTER N WITH CIRCUMFLEX BELOW
  ("n/^" ?ṋ) ;; LATIN SMALL LETTER N WITH CIRCUMFLEX BELOW
  ("O'~" ?Ṍ) ;; LATIN CAPITAL LETTER O WITH TILDE AND ACUTE
  ("o'~" ?ṍ) ;; LATIN SMALL LETTER O WITH TILDE AND ACUTE
  ("O\"~" ?Ṏ) ;; LATIN CAPITAL LETTER O WITH TILDE AND DIAERESIS
  ("o\"~" ?ṏ) ;; LATIN SMALL LETTER O WITH TILDE AND DIAERESIS
  ("O`-" ?Ṑ) ;; LATIN CAPITAL LETTER O WITH MACRON AND GRAVE
  ("o`-" ?ṑ) ;; LATIN SMALL LETTER O WITH MACRON AND GRAVE
  ("O'-" ?Ṓ) ;; LATIN CAPITAL LETTER O WITH MACRON AND ACUTE
  ("o'-" ?ṓ) ;; LATIN SMALL LETTER O WITH MACRON AND ACUTE
  ("P'" ?Ṕ) ;; LATIN CAPITAL LETTER P WITH ACUTE
  ("p'" ?ṕ) ;; LATIN SMALL LETTER P WITH ACUTE
  ("P/." ?Ṗ) ;; LATIN CAPITAL LETTER P WITH DOT ABOVE
  ("p/." ?ṗ) ;; LATIN SMALL LETTER P WITH DOT ABOVE
  ("R/." ?Ṙ) ;; LATIN CAPITAL LETTER R WITH DOT ABOVE
  ("r/." ?ṙ) ;; LATIN SMALL LETTER R WITH DOT ABOVE
;;  ("R/" ?Ṛ) ;; LATIN CAPITAL LETTER R WITH DOT BELOW
;;  ("r/" ?ṛ) ;; LATIN SMALL LETTER R WITH DOT BELOW
  ("R;" ?Ṛ) ;; LATIN CAPITAL LETTER R WITH DOT BELOW
  ("r;" ?ṛ) ;; LATIN SMALL LETTER R WITH DOT BELOW
  ("R-/" ?Ṝ) ;; LATIN CAPITAL LETTER R WITH DOT BELOW AND MACRON
  ("r-/" ?ṝ) ;; LATIN SMALL LETTER R WITH DOT BELOW AND MACRON
  ("R_" ?Ṟ) ;; LATIN CAPITAL LETTER R WITH LINE BELOW
  ("r_" ?ṟ) ;; LATIN SMALL LETTER R WITH LINE BELOW
  ("S/." ?Ṡ) ;; LATIN CAPITAL LETTER S WITH DOT ABOVE
  ("s/." ?ṡ) ;; LATIN SMALL LETTER S WITH DOT ABOVE
;;  ("S/" ?Ṣ) ;; LATIN CAPITAL LETTER S WITH DOT BELOW
;;  ("s/" ?ṣ) ;; LATIN SMALL LETTER S WITH DOT BELOW
  ("S;" ?Ṣ) ;; LATIN CAPITAL LETTER S WITH DOT BELOW
  ("s;" ?ṣ) ;; LATIN SMALL LETTER S WITH DOT BELOW
  ("S/.'" ?Ṥ) ;; LATIN CAPITAL LETTER S WITH ACUTE AND DOT ABOVE
  ("s/.'" ?ṥ) ;; LATIN SMALL LETTER S WITH ACUTE AND DOT ABOVE
  ("S/./v" ?Ṧ) ;; LATIN CAPITAL LETTER S WITH CARON AND DOT ABOVE
  ("s/./v" ?ṧ) ;; LATIN SMALL LETTER S WITH CARON AND DOT ABOVE
  ("S/./" ?Ṩ) ;; LATIN CAPITAL LETTER S WITH DOT BELOW AND DOT ABOVE
  ("s/./" ?ṩ) ;; LATIN SMALL LETTER S WITH DOT BELOW AND DOT ABOVE
  ("T/." ?Ṫ) ;; LATIN CAPITAL LETTER T WITH DOT ABOVE
  ("t/." ?ṫ) ;; LATIN SMALL LETTER T WITH DOT ABOVE
;;  ("T/" ?Ṭ) ;; LATIN CAPITAL LETTER T WITH DOT BELOW
;;  ("t/" ?ṭ) ;; LATIN SMALL LETTER T WITH DOT BELOW
  ("T;" ?Ṭ) ;; LATIN CAPITAL LETTER T WITH DOT BELOW
  ("t;" ?ṭ) ;; LATIN SMALL LETTER T WITH DOT BELOW
  ("T_" ?Ṯ) ;; LATIN CAPITAL LETTER T WITH LINE BELOW
  ("t_" ?ṯ) ;; LATIN SMALL LETTER T WITH LINE BELOW
  ("T/^" ?Ṱ) ;; LATIN CAPITAL LETTER T WITH CIRCUMFLEX BELOW
  ("t/^" ?ṱ) ;; LATIN SMALL LETTER T WITH CIRCUMFLEX BELOW
  ("U_\"" ?Ṳ) ;; LATIN CAPITAL LETTER U WITH DIAERESIS BELOW
  ("u_\"" ?ṳ) ;; LATIN SMALL LETTER U WITH DIAERESIS BELOW
  ("U/~" ?Ṵ) ;; LATIN CAPITAL LETTER U WITH TILDE BELOW
  ("u/~" ?ṵ) ;; LATIN SMALL LETTER U WITH TILDE BELOW
  ("U/^" ?Ṷ) ;; LATIN CAPITAL LETTER U WITH CIRCUMFLEX BELOW
  ("u/^" ?ṷ) ;; LATIN SMALL LETTER U WITH CIRCUMFLEX BELOW
  ("U'~" ?Ṹ) ;; LATIN CAPITAL LETTER U WITH TILDE AND ACUTE
  ("u'~" ?ṹ) ;; LATIN SMALL LETTER U WITH TILDE AND ACUTE
  ("U\"-" ?Ṻ) ;; LATIN CAPITAL LETTER U WITH MACRON AND DIAERESIS
  ("u\"-" ?ṻ) ;; LATIN SMALL LETTER U WITH MACRON AND DIAERESIS
  ("V~" ?Ṽ) ;; LATIN CAPITAL LETTER V WITH TILDE
  ("v~" ?ṽ) ;; LATIN SMALL LETTER V WITH TILDE
  ("V/" ?Ṿ) ;; LATIN CAPITAL LETTER V WITH DOT BELOW
  ("v/" ?ṿ) ;; LATIN SMALL LETTER V WITH DOT BELOW
  ("W`" ?Ẁ) ;; LATIN CAPITAL LETTER W WITH GRAVE
  ("w`" ?ẁ) ;; LATIN SMALL LETTER W WITH GRAVE
  ("W'" ?Ẃ) ;; LATIN CAPITAL LETTER W WITH ACUTE
  ("w'" ?ẃ) ;; LATIN SMALL LETTER W WITH ACUTE
  ("W\"" ?Ẅ) ;; LATIN CAPITAL LETTER W WITH DIAERESIS
  ("w\"" ?ẅ) ;; LATIN SMALL LETTER W WITH DIAERESIS
  ("W/." ?Ẇ) ;; LATIN CAPITAL LETTER W WITH DOT ABOVE
  ("w/." ?ẇ) ;; LATIN SMALL LETTER W WITH DOT ABOVE
  ("W/" ?Ẉ) ;; LATIN CAPITAL LETTER W WITH DOT BELOW
  ("w/" ?ẉ) ;; LATIN SMALL LETTER W WITH DOT BELOW
  ("X/." ?Ẋ) ;; LATIN CAPITAL LETTER X WITH DOT ABOVE
  ("x/." ?ẋ) ;; LATIN SMALL LETTER X WITH DOT ABOVE
  ("X\"" ?Ẍ) ;; LATIN CAPITAL LETTER X WITH DIAERESIS
  ("x\"" ?ẍ) ;; LATIN SMALL LETTER X WITH DIAERESIS
  ("Y/." ?Ẏ) ;; LATIN CAPITAL LETTER Y WITH DOT ABOVE
  ("y/." ?ẏ) ;; LATIN SMALL LETTER Y WITH DOT ABOVE
  ("Z^" ?Ẑ) ;; LATIN CAPITAL LETTER Z WITH CIRCUMFLEX
  ("z^" ?ẑ) ;; LATIN SMALL LETTER Z WITH CIRCUMFLEX
  ("Z/" ?Ẓ) ;; LATIN CAPITAL LETTER Z WITH DOT BELOW
  ("z/" ?ẓ) ;; LATIN SMALL LETTER Z WITH DOT BELOW
  ("Z_" ?Ẕ) ;; LATIN CAPITAL LETTER Z WITH LINE BELOW
  ("z_" ?ẕ) ;; LATIN SMALL LETTER Z WITH LINE BELOW
  ("h_" ?ẖ) ;; LATIN SMALL LETTER H WITH LINE BELOW
  ("t\"" ?ẗ) ;; LATIN SMALL LETTER T WITH DIAERESIS
  ("w/o" ?ẘ) ;; LATIN SMALL LETTER W WITH RING ABOVE
  ("y/o" ?ẙ) ;; LATIN SMALL LETTER Y WITH RING ABOVE
;;  ("a" ?ẚ) ;; LATIN SMALL LETTER A WITH RIGHT HALF RING
  ("f/." ?ẛ) ;; LATIN SMALL LETTER LONG S WITH DOT ABOVE

  ("A/" ?Ạ) ;; LATIN CAPITAL LETTER A WITH DOT BELOW
  ("a/" ?ạ) ;; LATIN SMALL LETTER A WITH DOT BELOW
  ("A)" ?Ả) ;; LATIN CAPITAL LETTER A WITH HOOK ABOVE
  ("a)" ?ả) ;; LATIN SMALL LETTER A WITH HOOK ABOVE
  ("A^'" ?Ấ) ;; LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND ACUTE
  ("a^'" ?ấ) ;; LATIN SMALL LETTER A WITH CIRCUMFLEX AND ACUTE
  ("A`^" ?Ầ) ;; LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND GRAVE
  ("a`^" ?ầ) ;; LATIN SMALL LETTER A WITH CIRCUMFLEX AND GRAVE
  ("A^)" ?Ẩ) ;; LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
  ("a^)" ?ẩ) ;; LATIN SMALL LETTER A WITH CIRCUMFLEX AND HOOK ABOVE
  ("A^~" ?Ẫ) ;; LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND TILDE
  ("a^~" ?ẫ) ;; LATIN SMALL LETTER A WITH CIRCUMFLEX AND TILDE
  ("A^/" ?Ậ) ;; LATIN CAPITAL LETTER A WITH CIRCUMFLEX AND DOT BELOW
  ("a^/" ?ậ) ;; LATIN SMALL LETTER A WITH CIRCUMFLEX AND DOT BELOW
  ("A'/u" ?Ắ) ;; LATIN CAPITAL LETTER A WITH BREVE AND ACUTE
  ("a'/u" ?ắ) ;; LATIN SMALL LETTER A WITH BREVE AND ACUTE
  ("A`/u" ?Ằ) ;; LATIN CAPITAL LETTER A WITH BREVE AND GRAVE
  ("a`/u" ?ằ) ;; LATIN SMALL LETTER A WITH BREVE AND GRAVE
  ("A)/u" ?Ẳ) ;; LATIN CAPITAL LETTER A WITH BREVE AND HOOK ABOVE
  ("a)/u" ?ẳ) ;; LATIN SMALL LETTER A WITH BREVE AND HOOK ABOVE
  ("A~/u" ?Ẵ) ;; LATIN CAPITAL LETTER A WITH BREVE AND TILDE
  ("a~/u" ?ẵ) ;; LATIN SMALL LETTER A WITH BREVE AND TILDE
  ("A/u/" ?Ặ) ;; LATIN CAPITAL LETTER A WITH BREVE AND DOT BELOW
  ("a/u/" ?ặ) ;; LATIN SMALL LETTER A WITH BREVE AND DOT BELOW
  ("E/" ?Ẹ) ;; LATIN CAPITAL LETTER E WITH DOT BELOW
  ("e/" ?ẹ) ;; LATIN SMALL LETTER E WITH DOT BELOW
  ("E)" ?Ẻ) ;; LATIN CAPITAL LETTER E WITH HOOK ABOVE
  ("e)" ?ẻ) ;; LATIN SMALL LETTER E WITH HOOK ABOVE
  ("E~" ?Ẽ) ;; LATIN CAPITAL LETTER E WITH TILDE
  ("e~" ?ẽ) ;; LATIN SMALL LETTER E WITH TILDE
  ("E^'" ?Ế) ;; LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND ACUTE
  ("e^'" ?ế) ;; LATIN SMALL LETTER E WITH CIRCUMFLEX AND ACUTE
  ("E`^" ?Ề) ;; LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND GRAVE
  ("e`^" ?ề) ;; LATIN SMALL LETTER E WITH CIRCUMFLEX AND GRAVE
  ("E^)" ?Ể) ;; LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
  ("e^)" ?ể) ;; LATIN SMALL LETTER E WITH CIRCUMFLEX AND HOOK ABOVE
  ("E~^" ?Ễ) ;; LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND TILDE
  ("e~^" ?ễ) ;; LATIN SMALL LETTER E WITH CIRCUMFLEX AND TILDE
  ("E^/" ?Ệ) ;; LATIN CAPITAL LETTER E WITH CIRCUMFLEX AND DOT BELOW
  ("e^/" ?ệ) ;; LATIN SMALL LETTER E WITH CIRCUMFLEX AND DOT BELOW
  ("I)" ?Ỉ) ;; LATIN CAPITAL LETTER I WITH HOOK ABOVE
  ("i)" ?ỉ) ;; LATIN SMALL LETTER I WITH HOOK ABOVE
  ("I/" ?Ị) ;; LATIN CAPITAL LETTER I WITH DOT BELOW
  ("i/" ?ị) ;; LATIN SMALL LETTER I WITH DOT BELOW
  ("O/" ?Ọ) ;; LATIN CAPITAL LETTER O WITH DOT BELOW
  ("o/" ?ọ) ;; LATIN SMALL LETTER O WITH DOT BELOW
  ("O)" ?Ỏ) ;; LATIN CAPITAL LETTER O WITH HOOK ABOVE
  ("o)" ?ỏ) ;; LATIN SMALL LETTER O WITH HOOK ABOVE
  ("O^'" ?Ố) ;; LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND ACUTE
  ("o^'" ?ố) ;; LATIN SMALL LETTER O WITH CIRCUMFLEX AND ACUTE
  ("O`^" ?Ồ) ;; LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND GRAVE
  ("o`^" ?ồ) ;; LATIN SMALL LETTER O WITH CIRCUMFLEX AND GRAVE
  ("O^)" ?Ổ) ;; LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
  ("o^)" ?ổ) ;; LATIN SMALL LETTER O WITH CIRCUMFLEX AND HOOK ABOVE
  ("O~^" ?Ỗ) ;; LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND TILDE
  ("o~^" ?ỗ) ;; LATIN SMALL LETTER O WITH CIRCUMFLEX AND TILDE
  ("O^/" ?Ộ) ;; LATIN CAPITAL LETTER O WITH CIRCUMFLEX AND DOT BELOW
  ("o^/" ?ộ) ;; LATIN SMALL LETTER O WITH CIRCUMFLEX AND DOT BELOW
  ("O')" ?Ớ) ;; LATIN CAPITAL LETTER O WITH HORN AND ACUTE
  ("o')" ?ớ) ;; LATIN SMALL LETTER O WITH HORN AND ACUTE
  ("O`)" ?Ờ) ;; LATIN CAPITAL LETTER O WITH HORN AND GRAVE
  ("o`)" ?ờ) ;; LATIN SMALL LETTER O WITH HORN AND GRAVE
  ("O))" ?Ở) ;; LATIN CAPITAL LETTER O WITH HORN AND HOOK ABOVE
  ("o))" ?ở) ;; LATIN SMALL LETTER O WITH HORN AND HOOK ABOVE
  ("O~)" ?Ỡ) ;; LATIN CAPITAL LETTER O WITH HORN AND TILDE
  ("o~)" ?ỡ) ;; LATIN SMALL LETTER O WITH HORN AND TILDE
  ("O)/" ?Ợ) ;; LATIN CAPITAL LETTER O WITH HORN AND DOT BELOW
  ("o)/" ?ợ) ;; LATIN SMALL LETTER O WITH HORN AND DOT BELOW
  ("U/" ?Ụ) ;; LATIN CAPITAL LETTER U WITH DOT BELOW
  ("u/" ?ụ) ;; LATIN SMALL LETTER U WITH DOT BELOW
  ("U)" ?Ủ) ;; LATIN CAPITAL LETTER U WITH HOOK ABOVE
  ("u)" ?ủ) ;; LATIN SMALL LETTER U WITH HOOK ABOVE
  ("U')" ?Ứ) ;; LATIN CAPITAL LETTER U WITH HORN AND ACUTE
  ("u')" ?ứ) ;; LATIN SMALL LETTER U WITH HORN AND ACUTE
  ("U`)" ?Ừ) ;; LATIN CAPITAL LETTER U WITH HORN AND GRAVE
  ("u`)" ?ừ) ;; LATIN SMALL LETTER U WITH HORN AND GRAVE
  ("U))" ?Ử) ;; LATIN CAPITAL LETTER U WITH HORN AND HOOK ABOVE
  ("u))" ?ử) ;; LATIN SMALL LETTER U WITH HORN AND HOOK ABOVE
  ("U~)" ?Ữ) ;; LATIN CAPITAL LETTER U WITH HORN AND TILDE
  ("u~)" ?ữ) ;; LATIN SMALL LETTER U WITH HORN AND TILDE
  ("U)/" ?Ự) ;; LATIN CAPITAL LETTER U WITH HORN AND DOT BELOW
  ("u)/" ?ự) ;; LATIN SMALL LETTER U WITH HORN AND DOT BELOW
  ("Y`" ?Ỳ) ;; LATIN CAPITAL LETTER Y WITH GRAVE
  ("y`" ?ỳ) ;; LATIN SMALL LETTER Y WITH GRAVE
  ("Y/" ?Ỵ) ;; LATIN CAPITAL LETTER Y WITH DOT BELOW
  ("y/" ?ỵ) ;; LATIN SMALL LETTER Y WITH DOT BELOW
  ("Y)" ?Ỷ) ;; LATIN CAPITAL LETTER Y WITH HOOK ABOVE
  ("y)" ?ỷ) ;; LATIN SMALL LETTER Y WITH HOOK ABOVE
  ("Y~" ?Ỹ) ;; LATIN CAPITAL LETTER Y WITH TILDE
  ("y~" ?ỹ) ;; LATIN SMALL LETTER Y WITH TILDE

;; Sundries
;;  ("" ?∘) ;; RING OPERATOR
;;  ("" ?∙) ;; BULLET OPERATOR
  ("/rt" ?√) ;; SQUARE ROOT
  ("~=" ?≅) ;; APPROXIMATELY EQUAL TO
  ("~~" ?≈) ;; ALMOST EQUAL TO
  ("-=" ?≡) ;; IDENTICAL TO

 )

;;; utf-8_input.el ends here
